# Stocks ML
Apply artificial intelligence to the stock market. StocksML can build an
entire trading strategy from scratch and simulate the performance of that
strategy against any specified benchmark.

Read the docs here: https://stocks-ml.readthedocs.io/en/latest/